// Library:       WebSphere MQ
// Component:     MQ.NET Sample Programs
// Part:          NMQSPUT.CS
//
// Description:   Sample C# program that puts messages to a named
//                queue.
//
//                NMQSPUT has 3 parameters:
//                - the name of a queue (required)
//                - the name of a queue manager (optional)
//                - the definition of a channel (optional)
//
//                If no queue manager name is given, the queue manager
//                defaults to the default local queue manager. If a
//                channel is defined, it should have the same format
//                as the MQSERVER environment variable.
//  <START_COPYRIGHT> 
//  Licensed Materials - Property of IBM 
//                   
//  5724-B41         
//  (C) Copyright IBM Corp. 1994, 2003 All Rights Reserved. 
//                   
//  US Government Users Restricted Rights - Use, duplication or 
//  disclosure restricted by GSA ADP Schedule Contract with 
//  IBM Corp.        
//  <END_COPYRIGHT>  

using System;
using IBM.WMQ;

namespace nmqsput
{
	/// <summary>
	/// Summary description for nmqsput.
	/// </summary>
	class nmqsput
	{
		/// <summary>
		/// The main entry point for the application.
		/// </summary>
		[STAThread]
		static int Main(String[] args)
		{
			MQQueueManager      mqQMgr;          // MQQueueManager instance
			MQQueue             mqQueue;         // MQQueue instance
			MQMessage           mqMsg;           // MQMessage instance
			MQPutMessageOptions mqPutMsgOpts;    // MQPutMessageOptions instance
			String              queueName;       // Name of queue to use
			int                 msgLen;          // Message length
			String              message;         // Message buffer

			System.Console.WriteLine( "Sample NMQSPUT start" );
			if (args.Length == 0) 
			{
				System.Console.WriteLine("Required parameter missing - queue name" );
				return( (int)99 );
			}
			else 
			{
				queueName = args[0];
			}

			///
			/// Try to create an MQQueueManager instance 
			/// 
			try 
			{
				if (args.Length > 2) 
				{
					// queue name, queue manager name, channel definition all provided

					// Break down the channel definition,
					// which is of the form "channel-name/transport-type/connection-name".
					String channelDefinition = args[2];
					String channelName = "";
					String transportType = "";
					String connectionName = "";
					char[] separator = {'/'};
					String[] parts;
					parts = channelDefinition.Split( separator );
					if (parts.Length > 0) channelName = parts[0];
					if (parts.Length > 1) transportType = parts[1];
					if (parts.Length > 2) connectionName = parts[2];
					mqQMgr = new MQQueueManager( args[1], channelName, connectionName );
				}
				else
					if (args.Length == 2) 
				{
					// queue name, queue manager name provided
					mqQMgr = new MQQueueManager( args[1] );
				}
				else
				{
					// queue name provided - use default queue manager
					mqQMgr = new MQQueueManager();
				}
			}
			catch (MQException mqe) 
			{
				// stop if failed
				System.Console.WriteLine( "create of MQQueueManager ended with " + mqe.Message );
				return( (int)mqe.Reason );
			}

			///
			/// Try to open the queue
			///
			try 
			{
				mqQueue = mqQMgr.AccessQueue( queueName, 
					                          MQC.MQOO_OUTPUT                   // open queue for output
					                          + MQC.MQOO_FAIL_IF_QUIESCING );   // but not if MQM stopping
			}
			catch (MQException mqe) 
			{
				// stop if failed
				System.Console.WriteLine( "MQQueueManager::AccessQueue ended with " + mqe.Message );
				return( (int)mqe.Reason );
			}

			///
			/// Read lines from the console and put them to the message queue
			/// Loop until end of input, or there is a failure
			/// 
			bool isContinue = true;
			while (isContinue) 
			{
				message = System.Console.ReadLine();
				msgLen = message.Length;

				if (msgLen > 0) 
				{
					// put the next message to the queue
					mqMsg = new MQMessage();
					mqMsg.WriteString( message );
					mqMsg.Format = MQC.MQFMT_STRING;
					mqPutMsgOpts = new MQPutMessageOptions();
					try
					{
						mqQueue.Put( mqMsg, mqPutMsgOpts );
					}
					catch (MQException mqe)
					{
						// report the error
						System.Console.WriteLine( "MQQueue::Put ended with " + mqe.Message );
					}
				}
				else 
				{
					// quit loop when empty line is read
					isContinue = false;
				}
			}

			System.Console.WriteLine( "Sample NMQSPUT end" );
			return (0);
		}
	}
}
